@@ -28,12 +28,6 @@
 
 using System;
 using System.Threading;
-using System.Collections.Generic;
-using MonoDevelop.Database.Sql;
-using MonoDevelop.Core;
-using MonoDevelop.Core.Gui;
-using MonoDevelop.Ide.Gui.Pads;
-using MonoDevelop.Components.Commands;
 using MonoDevelop.Ide.Gui.Components;
 
 namespace MonoDevelop.Database.ConnectionManager
