@@ -813,42 +813,32 @@ namespace MonoDevelop.Database.Sql
 		
 		public virtual string GetSelectQuery (TableSchema table)
 		{
-			StringBuilder sb = new StringBuilder ("SELECT ");
-			bool coma = false;
+			ISqlDialect dialect =  this.ConnectionPool.DbFactory.Dialect;
+			IdentifierExpression tableId = new IdentifierExpression (table.Name);
+			List<IdentifierExpression> columns = new List<IdentifierExpression>();
+			
 			foreach (ColumnSchema col in table.Columns) {
-				if (coma)
-					sb.AppendFormat(",");
-				coma = true;
-				sb.AppendLine ();
-				sb.AppendFormat ("{0}{1}", Convert.ToString (Convert.ToChar (9)), col.Name);
+				columns.Add(new IdentifierExpression(col.Name));
 			}
-			sb.AppendLine ();
-			sb.AppendFormat ("FROM {0}", table.Name);
-			return sb.ToString ();
+			
+			SelectStatement sel = new SelectStatement (new FromTableClause (tableId),columns);
+			return dialect.GetSql(sel);
 		}
 
 		public virtual string GetUpdateQuery (TableSchema table)
 		{
-			StringBuilder sb = new StringBuilder ("UPDATE ");
-			sb.AppendFormat ("{0} {1}{1}{2}SET", table.Name, Convert.ToString (Convert.ToChar (9)), Environment.NewLine);
-			bool coma = false;
+			ISqlDialect dialect =  this.ConnectionPool.DbFactory.Dialect;
+			IdentifierExpression tableId = new IdentifierExpression (table.Name);
+			List<IdentifierExpression> columns = new List<IdentifierExpression>();
+			List<IExpression> values = new List<IExpression>();
+			
 			foreach (ColumnSchema col in table.Columns) {
-				if (coma)
-					sb.AppendFormat(",");
-				coma = true;
-				sb.AppendLine ();
-				if (col.DataType.FullName.IndexOf ("varchar", StringComparison.OrdinalIgnoreCase) > -1 ||
-				    col.DataType.FullName.IndexOf ("char", StringComparison.OrdinalIgnoreCase) > -1 ||
-				    col.DataType.FullName.IndexOf ("nvarchar", StringComparison.OrdinalIgnoreCase) > -1 ||
-				    col.DataType.FullName.IndexOf ("varbinary", StringComparison.OrdinalIgnoreCase) > -1 ||
-				    col.DataType.FullName.IndexOf ("nchar", StringComparison.OrdinalIgnoreCase) > -1)				
-					sb.AppendFormat ("{2}{0} = <{1}({3})> ", col.Name, col.DataType.FullName, Convert.ToString (Convert.ToChar (9)), col.DataType.LengthRange.Max);
-				else
-					sb.AppendFormat ("{2}{0} = <{1}> ", col.Name, col.DataType.FullName, Convert.ToString (Convert.ToChar (9)));
+				columns.Add(new IdentifierExpression(col.Name));				
+				values.Add(new IdentifierExpression(col.DataTypeName));				
 			}
-			sb.AppendLine ();
-			sb.Append ("WHERE ");
-			return sb.ToString ();
+			
+			UpdateStatement upd = new UpdateStatement (tableId, columns, values);
+			return dialect.GetSql(upd);
 		}
 
 		public virtual string GetInsertQuery (TableSchema table)
